@@ -1,10 +1,13 @@
 from dateutil.relativedelta import relativedelta
 
-def vested(quantity, check_date, grant_date, vest_rate):
+def vested(quantity, check_date, grant_date, vest_rate, vest_interval='m'):
     elapsed = relativedelta(check_date, grant_date)
     if elapsed.years >= 3:
         return (quantity, 0)
-    v = int((12 * elapsed.years + elapsed.months) * vest_rate * quantity)
+    if vest_interval == 'm':
+        v = int((12 * elapsed.years + elapsed.months) * vest_rate * quantity)
+    elif vest_interval == 'y':
+        v = int(elapsed.years * vest_rate * quantity)
     return (v, quantity - v)
 
 def vesting_profile(grant_quantity, grant_date, vesting_rate,
